/*

Randomization Inference. Randomly re-assign IPW among observations and run main analysis using the re-assigned IPW. Do this 1000 times to get a null distribution.

----------------------------------------------------------------------------- */

* --------- Program to re-assign IPW and save point estimate

cap program drop getbeta
program getbeta
    syntax [aw] [if], ///
        betamat(name) /// matrix in which to store point estimates
        outvar(varname) /// outcome variable
        predvar(varname) /// name of predictor variable
        [controls(string)] /// list of control variables

    * re-assign predictor variable
    preserve
    qui: if !mi("`if'") keep `if'
    gen orign = _n
    gen double r1 = runiform()
    gen double r2 = runiform()
    sort r1 r2
    gen nullpredvar = `predvar'[orign]

    * regression using null predictor variable
    qui: regress `outvar' nullpredvar `controls' [`weight'`exp'], robust

    * save coefficient in matrix
    cap confirm matrix `betamat'
    if _rc matrix `betamat' = _b["nullpredvar"]
    else matrix `betamat' = `betamat' \ _b["nullpredvar"]
    restore
end

* ------------------------------------------------------------------------------
* Program to plot and save histogram of null estimates

cap program drop plothist
program plothist, rclass
    syntax, ///
        nullbetamat(name) /// matrix with null betas
        pdffile(string) /// output pdf name
        realbeta(real) /// real beta value

    * put null betas into data frame
    preserve
    clear
    matrix colnames `nullbetamat' = nullbeta
    svmat `nullbetamat', names(col)

    * get range of histogram
    qui: summ nullbeta
    loc xmin = min(r(min), `realbeta')
    loc xmax = max(r(max), `realbeta')
    gen bin = round(100 * (nullbeta - r(min)) / (r(max) - r(min)))
    egen modebin = mode(bin), maxmode
    qui: count if bin == modebin
    loc ymax = ceil(100 * (r(N) / 1000))

    * get p value
    qui: count if abs(nullbeta) >= abs(`realbeta')
    loc pval: di %04.3f `=r(N) / c(N)'
    di "This is the p value: `pval'"
    return local pval = "`pval'"

    * plot histogram
    loc xlim = 1.15 * max(abs(`xmin'), abs(`xmax'))
    loc x_text = `xlim' * 0.5
    loc y_text = `ymax' * 0.75
    twoway (histogram nullbeta, percent bin(100)) || (pci 0 `realbeta' `ymax' `realbeta', lpattern(solid) lc(red) lw(medium)), xscale(r(-`xlim' `xlim')) xlabel(#5) graphregion(color(white)) xtitle(Coefficient) legend(off) text(`y_text' `x_text' "p=`pval'", color(red) size(large))
    graph export "`pdffile'.pdf", replace
    restore
end

* ------------------------------------------------------------------------------
* Program to run real regression, get null betas, and make plot

cap program drop mkrandplot
program mkrandplot
    syntax [aw] [if], ///
        outvar(varname) /// outcome variable
        predvar(varlist) /// predictor variables (ipw)
        pdffile(string) /// output pdf file
        [controls(string) /// list of controls
        rowname(string) /// row name for pvalue matrix
        store(name) /// name of new pvalue matrix
        merge(name)] /// name of pvalue matrix to merge with

        * use the same seed (thus the same data-scrambles) for every plot
        version 14: set seed 0765913106

        * get real estimate and store beta
        regress `outvar' `predvar' `controls' [`weight'`exp'] `if', robust
        gen insamp = e(sample)
        loc realbeta = _b["`predvar'"]

        * get null betas
        set matsize 1000
        tempname nullbetas
        forvalues i = 1/1000 {
            if (mod(`i', 100) == 0) di "Regression `i' for outcome=`outvar', predvar=`predvar' `if'..."
            getbeta [`weight'`exp'] if insamp, betamat(`nullbetas') controls(`controls') outvar(`outvar') predvar(`predvar')
        }
        drop insamp

        * make and save plot
        plothist, nullbetamat(`nullbetas') pdffile(`pdffile') realbeta(`realbeta')
        loc pval = r(pval)

        * save pvalue to matrix
        if !mi("`store'") {
            matrix `store' = (0, `pval')
            global rownames_`store' = `" `"`rowname'"' "'
        }
        if !mi("`merge'") {
            confirm matrix `merge'
            matrix `merge' = `merge' \ (0, `pval')
            global rownames_`merge' = `"${rownames_`merge'} `"`rowname'"' "'
        }
end

* ------------------------------------------------------------------------------
* Program to add row header to the pvalue table

cap program drop pvaltab_rh
program pvaltab_rh
    syntax, ///
        rowname(string) /// name of row
        [store(string) /// store in new table
        merge(string)] /// merge with previous results

    * save results matrix
    if !mi("`store'") {
        matrix `store' = (1, .)
        global rownames_`store' = `" "`rowname'" "'
    }
    else if !mi("`merge'") {
        confirm matrix `merge'
        matrix `merge' = `merge' \ (1, .)
        global rownames_`merge' = `"${rownames_`merge'} "`rowname'" "'
    }
end

* ------------------------------------------------------------------------------
* Writes pvalue table to tex

cap program drop pvaltab_write
program pvaltab_write
    syntax using, ///
        replay(string) /// name of stored matrix
        [replace] /// replace output tex file

    * initialize file
    tempname f pvalmat
    file open `f' `using', write `replace'
    file write `f' "\begin{tabular}{lc}" _n
    file write `f' "\hline\noalign{\smallskip} & P-value \\" _n
    file write `f' "& (1) \\" _n
    file write `f' "\noalign{\smallskip}\hline\noalign{\smallskip}" _n

    * iterate through rows of matrix, writing to tex
    matrix `pvalmat' = `replay'
    loc n = rowsof(`pvalmat')
    forvalues i = 1/`n' {
        loc name: word `i' of ${rownames_`replay'}
        if `pvalmat'[`i', 1] file write `f' `"\textbf{`name'} & \\"' _n
        else {
            loc pval = `pvalmat'[`i', 2]
            loc pval: di %4.3f `pval'
            file write `f' `"`name' & `pval' \\"' _n
        }
    }

    * close file
    macro drop rownames_`replay'
    matrix drop `pvalmat'
    file write `f' "\noalign{\smallskip}\hline\end{tabular}"
    file close `f'
end

* ------------------------------------------------------------------------------
* Make all plots

cap program drop randinf_all
program randinf_all
    syntax, ///
        ipwdatalist_main(string asis) /// dataset with ipws
        pchjobsdata_main(string) /// dataset with pchjobs
        wtvar_main(string) /// what variable to weight by
        ipwdatalist98(string asis) /// ipw name for 98-03 and 98-13
        pchjobsdata98(string) /// pchjobs name for 98-03 and 98-13
        wtvar98(string) /// name of variable to weight by for 98-03 and 98-13
        outfldr_plot(string) /// output folder for plots
        outfldr_tab(string) /// output folder for table
        [convars_main(string) /// control variables for most muni regs
        convars98(string) /// control variables for 1998-2013 and 1998-2003
        nostd] /// do not standardize pchjobs

    * --- Make outfldrs if they do not exist
    foreach dir in `outfldr_plot' `outfldr_tab' {
        confirmdir "`dir'"
        if real(r(confirmdir)) mkdir "`dir'"
    }

    * --- Prepare 1998-2013
    run maketables
    tempfile mundata_9813
    prepdata_9813, ipwdatalist(`ipwdatalist98') pchjobsdata(`pchjobsdata98') wtvar(`wtvar98') data(`mundata_9813') `std'

    * --- Prepare 1998-2003
    tempfile mundata_9803
    prepdata_9803, ipwdatalist(`ipwdatalist98') pchjobsdata(`pchjobsdata98') wtvar(`wtvar98') data(`mundata_9803') `std'

    * --- Prepare 2007-10/11
    tempfile mundata_main
    prepdata_main, ipwdatalist(`ipwdatalist_main') pchjobsdata(`pchjobsdata_main') wtvar(`wtvar_main') data(`mundata_main') `std'

    * --- Prepare state data
    tempfile statedata
    prepdata_state, ipwdatalist(`ipwdatalist_main') pchjobsdata(`pchjobsdata_main') wtvar(`wtvar_main') data(`statedata') `std'

    * --------------------------------------------------------------------------
    * Make the plots

    * --- First stage

    pvaltab_rh, rowname("First Stage") store(pvalmat)

    * 1998-2013
    use `mundata_9813', clear
    mkrandplot [aw=`wtvar98'], outvar(pchjobs2013) predvar(ipw2013_num1) controls(`convars98') pdffile("`outfldr_plot'/fs_9813") merge(pvalmat) rowname("1998-2013")

    * 1998-2003
    use `mundata_9803', clear
    mkrandplot [aw=`wtvar98'], outvar(pchjobs2003) predvar(ipw2003_num1) controls(`convars98') pdffile("`outfldr_plot'/fs_9803") merge(pvalmat) rowname("1998-2003")

    * 2007-2010
    use `mundata_main', clear
    mkrandplot [aw=`wtvar_main'], outvar(pchjobs2010) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/fs_0710") merge(pvalmat) rowname("2007-2010")

    * 2007-2011
    mkrandplot [aw=`wtvar_main'], outvar(pchjobs2011) predvar(ipw2011_num1) controls(`convars_main') pdffile("`outfldr_plot'/fs_0711") merge(pvalmat) rowname("2007-2011")

    * --- All homicides

    pvaltab_rh, rowname("$\Delta$ Total Homicide Rates") merge(pvalmat)

    * 1998-2013
    use `mundata_9813', clear
    mkrandplot [aw=`wtvar98'], outvar(homdiff_9813) predvar(ipw2013_num1) controls(`convars98') pdffile("`outfldr_plot'/allhom_9813") merge(pvalmat) rowname("1998-2013")

    * 1998-2003
    use `mundata_9803', clear
    mkrandplot [aw=`wtvar98'], outvar(homdiff_9803) predvar(ipw2003_num1) controls(`convars98') pdffile("`outfldr_plot'/allhom_9803") merge(pvalmat) rowname("1998-2003")

    * full sample 2007-10
    use `mundata_main', clear
    mkrandplot [aw=`wtvar_main'], outvar(homdiff_inegi_ratelong3) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/allhom_full") merge(pvalmat) rowname("Full Sample (2007-10)")

    * no dto sample, 2007-10
    mkrandplot if cartel == 0 [aw=`wtvar_main'] , outvar(homdiff_inegi_ratelong3) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/allhom_no") merge(pvalmat) rowname("No DTO Sample (2007-10)")

    * any dto sample, 2007-10
    mkrandplot if cartel == 1 [aw=`wtvar_main'] , outvar(homdiff_inegi_ratelong3) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/allhom_any") merge(pvalmat) rowname("Any DTO Sample (2007-10)")

    * major dto sample, 2007-10
    mkrandplot if C_major == 1 [aw=`wtvar_main'] , outvar(homdiff_inegi_ratelong3) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/allhom_maj") merge(pvalmat) rowname("Major DTO Sample (2007-10)")

    * full sample 2007-11
    mkrandplot [aw=`wtvar_main'], outvar(homdiff_inegi_ratelong4) predvar(ipw2011_num1) controls(`convars_main') pdffile("`outfldr_plot'/allhom_0711") merge(pvalmat) rowname("Full Sample (2007-11)")

    * --- Drug-related homicides

    pvaltab_rh, rowname("$\Delta$ Drug-Related Homicide Rates") merge(pvalmat)

    * full sample 2007-10
    mkrandplot [aw=`wtvar_main'], outvar(homdiff_rate_long3) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/drhom_full") merge(pvalmat) rowname("Full Sample (2007-10)")

    * no dto sample, 2007-10
    mkrandplot if cartel == 0 [aw=`wtvar_main'], outvar(homdiff_rate_long3) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/drhom_no") merge(pvalmat) rowname("No DTO Sample (2007-10)")

    * any dto sample, 2007-10
    mkrandplot if cartel == 1 [aw=`wtvar_main'], outvar(homdiff_rate_long3) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/drhom_any") merge(pvalmat) rowname("Any DTO Sample (2007-10)")

    * major dto sample, 2007-10
    mkrandplot if C_major == 1 [aw=`wtvar_main'], outvar(homdiff_rate_long3) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/drhom_maj") merge(pvalmat) rowname("Major DTO Sample (2007-10)")

    * full sample 2007-10, young male low-skill
    mkrandplot [aw=`wtvar_main'], outvar(homdiff_rate_long3) predvar(ipw2010_m_num1) controls(`convars_main') pdffile("`outfldr_plot'/drhom_ymls") merge(pvalmat) rowname("Full Sample, Young Low-Skill Men (2007-10)")

    * full sample 2007-10, residual group
    mkrandplot [aw=`wtvar_main'], outvar(homdiff_rate_long3) predvar(ipw2010_f_num1) controls(`convars_main') pdffile("`outfldr_plot'/drhom_resid") merge(pvalmat) rowname("Full Sample, Residual Group (2007-10)")

    * --- Cocaine seizures

    pvaltab_rh, rowname("$\Delta$ Log Val. Cocaine Seizures") merge(pvalmat)

    * full sample, 2007-10
    mkrandplot [aw=`wtvar_main'], outvar(logValueFor_total3diff) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/cocconf_full") merge(pvalmat) rowname("Full Sample (2007-10)")

    * no dto sample, 2007-10
    mkrandplot if cartel == 0 [aw=`wtvar_main'], outvar(logValueFor_total3diff) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/cocconf_no") merge(pvalmat) rowname("No DTO Sample (2007-10)")

    * any dto sample, 2007-10
    mkrandplot if cartel == 1 [aw=`wtvar_main'], outvar(logValueFor_total3diff) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/cocconf_any") merge(pvalmat) rowname("Any DTO Sample (2007-10)")

    * major dto sample, 2007-10
    mkrandplot if C_major == 1 [aw=`wtvar_main'], outvar(logValueFor_total3diff) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/cocconf_maj") merge(pvalmat) rowname("Major DTO Sample (2007-10)")

    * --- Non-cocaine seizures

    pvaltab_rh, rowname("$\Delta$ Log Val. Non-Coc. Seizures") merge(pvalmat)

    * full sample, 2007-10
    mkrandplot [aw=`wtvar_main'], outvar(logValueDom_total3diff) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/ncocconf_full") merge(pvalmat) rowname("Full Sample (2007-10)")

    * no dto sample, 2007-10
    mkrandplot if cartel == 0 [aw=`wtvar_main'], outvar(logValueDom_total3diff) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/ncocconf_no") merge(pvalmat) rowname("No DTO Sample (2007-10)")

    * any dto sample, 2007-10
    mkrandplot if cartel == 1 [aw=`wtvar_main'], outvar(logValueDom_total3diff) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/ncocconf_any") merge(pvalmat) rowname("Any DTO Sample (2007-10)")

    * major dto sample, 2007-10
    mkrandplot if C_major == 1 [aw=`wtvar_main'], outvar(logValueDom_total3diff) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/ncocconf_maj") merge(pvalmat) rowname("Major DTO Sample (2007-10)")

    * --- Opinions

    pvaltab_rh, rowname("Change in Agreement (2005-12)") merge(pvalmat)

    * politicians improve wellbeing
    use `statedata', clear
    mkrandplot [aw=`wtvar_main'], outvar(diffpol_contribute) predvar(ipw2010_num1) pdffile("`outfldr_plot'/agree_polimp") merge(pvalmat) rowname("Politicians Improve Wellbeing")

    * more opportunities than in past
    mkrandplot [aw=`wtvar_main'], outvar(diffopportunity) predvar(ipw2010_num1) pdffile("`outfldr_plot'/agree_moreopp") merge(pvalmat) rowname("More Opportunities Than In Past")

    * Mexico is democratic
    mkrandplot [aw=`wtvar_main'], outvar(diffstatus_dem) predvar(ipw2010_num1) pdffile("`outfldr_plot'/agree_mexdem") merge(pvalmat) rowname("Mexico is Democratic")

    * --- Local politics: any change

    pvaltab_rh, rowname("Local Politics: Any Change (2007-10)") merge(pvalmat)

    * any change (full sample)
    use `mundata_main', clear
    mkrandplot [aw=`wtvar_main'], outvar(anychange0710) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/anych_full") merge(pvalmat) rowname("Full Sample")

    * column 2 - any change (no DTO sample)
    mkrandplot if cartel == 0 [aw=`wtvar_main'], outvar(anychange0710) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/anych_no") merge(pvalmat) rowname("No DTO Sample")

    * column 3 - any change (any DTO sample)
    mkrandplot if cartel == 1 [aw=`wtvar_main'], outvar(anychange0710) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/anych_any") merge(pvalmat) rowname("Any DTO Sample")

    * column 4 - any change (major DTO sample)
    mkrandplot if C_major == 1 [aw=`wtvar_main'], outvar(anychange0710) predvar(ipw2010_num1) controls(`convars_main') pdffile("`outfldr_plot'/anych_maj") merge(pvalmat) rowname("Major DTO Sample")

    * --- Produce table
    pvaltab_write using "`outfldr_tab'/pvaltab.tex", replay(pvalmat) replace
end
