/*

Programs used to create percent change jobs and ipw variables.

----------------------------------------------------------------------------- */

* --------- Prepare labor by Mexican municpality x industry

cap program drop preplabor
program preplabor
    syntax, ///
        outfile(string) /// name of output file
        indcodevar(varname) /// name of industry code variable
        [ymls(string)] /// path to ymls data

    * create 3-digit code and merge with gender ratios by municipality/industry
    ren municipio id_mun
    if mi("`ymls'") loc ymlspath = "../../main/data_prepped/ymls_mun_ind"
    else loc ymlspath = "../data_prepped/ymls_mun_ind_`ymls'"
    merge m:1 id_mun subs using "`ymlspath'", keep(master match)

    * for obs that don't merge, impute the median share ymls
    qui: summ shymls, d
    replace shymls = r(p50) if _merge == 1
    drop _merge

    * create estimated ymls and other employment
    gen totemp_m = totemp * shymls
    gen totemp_f = totemp * (1 - shymls)

    * reshape to have separate municipality x industry employment variables for each year
    reshape wide totemp*, i(id_mun `indcodevar') j(year)
    ren totemp_m* totemp*_m
    ren totemp_f* totemp*_f

    * national employment in 2007
    bys `indcodevar': egen natemp2007 = total(totemp2007)

    * save
    keep id_mun `indcodevar' totemp* natemp*
    save `outfile'
end

* ------------------------------------------------------------------------------
* Construct percent changes in jobs

cap program drop makepchjobs
program makepchjobs
    syntax, ///
        indata_emp(string) /// employment data
        indata_denom(string) /// denominator data
        denomvar(string) /// denominator variable
        outfile(string) /// output dataset name

    * create municipal employment (preserve missings)
    use `indata_emp', clear
    foreach v of var totemp* {
        bys id_mun: egen mun_`v' = total(`v'), missing
    }
    keep id_mun mun_totemp*
    duplicates drop

    * merge with denominator
    merge 1:1 id_mun using `indata_denom', keep(match) nogen keepusing(`denomvar')

    * create percent changes in jobs
    foreach t in 2010 2011 {
        gen pchjobs`t' = (mun_totemp`t' - mun_totemp2007) / `denomvar'
        gen pchjobs`t'_m = (mun_totemp`t'_m - mun_totemp2007_m) / `denomvar'
        gen pchjobs`t'_f = (mun_totemp`t'_f - mun_totemp2007_f) / `denomvar'
    }
    keep id_mun pchjobs* mun_totemp2007 mun_totemp2010 mun_totemp2011
    save "`outfile'", replace
end

* ------------------------------------------------------------------------------
* Construct IPW

cap program drop makeipw
program makeipw
    syntax, ///
        indata_emp(string) /// employment data
        indata_chexp(string) /// change in exports data
        indata_denom(string) /// denominator data
        denomvar(string) /// denominator variable
        indcodevar(string) /// name of industry code variable
        outfile(string) /// output dataset name

    * merge employment with predicted export changes
    use `indata_emp', clear
    merge m:1 `indcodevar' using `indata_chexp', keep(master match)
    assert(_merge == 3) if "`indcodevar'" == "rama"
    replace chexp2010 = 0 if _merge == 1
    replace chexp2011 = 0 if _merge == 1

    * merge with denominator
    merge m:1 id_mun using `indata_denom', keep(match) nogen keepusing(`denomvar')

    * construct instrument
    foreach t in 2010 2011 {
        gen ipw`t' = (totemp2007 / natemp2007) * chexp`t' / `denomvar'
        gen ipw`t'_m = (totemp2007_m / natemp2007) * chexp`t' / `denomvar'
        gen ipw`t'_f = (totemp2007_f / natemp2007) * chexp`t' / `denomvar'
    }
    collapse (sum) ipw* (count) totemp2007 totemp2010 totemp2011, by(id_mun)
    foreach t in 2010 2011 {
        replace ipw`t' = . if totemp`t' == 0 | totemp2007 == 0
        replace ipw`t'_m = . if totemp`t' == 0 | totemp2007 == 0
        replace ipw`t'_f = . if totemp`t' == 0 | totemp2007 == 0
    }
    drop totemp2007 totemp2010 totemp2011

    * save
    isid id_mun
    compress
    save `outfile', replace
end

* ------------------------------------------------------------------------------
* Collapse percent change jobs to the state level

cap program drop pchjobs_state
program pchjobs_state
    syntax, ///
        denomdta(string) /// dataset with denominator
        denomvar(string) /// denominator variable in pchjobs
        infile(string) /// input pchjobs data
        outfile(string) /// output pchjobs state-level data

    use "`infile'", clear

    * merge with denominator
    merge 1:1 id_mun using `denomdta', assert(using match) nogen keepusing(`denomvar') keep(match)
    gen ent = floor(id_mun / 1000)

    * drop rural municipalities
    ren id_mun id_municipio
    merge 1:1 id_municipio using "../../main/data_raw/mun_characteristics.dta", assert(using match) keep(match) nogen keepusing(tipo_municipio)
    drop if tipo_municipio == "RU"

    * multiply percent changes in jobs by denominator to get level changes in jobs
    foreach suffix in 2010 2010_m 2010_f 2011 2011_m 2011_f {
        gen chjobs`suffix' = pchjobs`suffix' * `denomvar'
    }

    * sum job changes and denominator within states
    collapse (sum) chjobs* `denomvar', by(ent)

    * create percent changes in jobs
    foreach v of var chjobs* {
        gen p`v' = `v' / `denomvar'
    }

    * save
    keep ent pchjobs*
    save "`outfile'", replace
end

* ------------------------------------------------------------------------------
* Collapse ICW to the state level

cap program drop ipw_state
program ipw_state
    syntax, ///
        denomdta(string) /// dataset with denominator
        denomvar(string) /// denominator variable in pchjobs
        infile(string) /// input pchjobs data
        outfile(string) /// output pchjobs state-level data

    use "`infile'", clear

    * merge with denominator
    merge 1:1 id_mun using `denomdta', assert(using match) nogen keepusing(`denomvar')
    gen ent = floor(id_mun / 1000)

    * drop rural municipalities
    ren id_mun id_municipio
    merge 1:1 id_municipio using "../../main/data_raw/mun_characteristics.dta", keep(match) nogen keepusing(tipo_municipio)
    drop if tipo_municipio == "RU"

    * multiply ipw by denominator to get level changes in "ip" (not per worker)
    foreach suffix in 2010 2010_m 2010_f 2011 2011_m 2011_f {
        gen ip`suffix' = ipw`suffix' * `denomvar'
    }

    * sum ip and denominator within states
    drop ipw*
    collapse (sum) ip* `denomvar', by(ent)

    * create state-level ipw
    foreach suffix in 2010 2010_m 2010_f 2011 2011_m 2011_f {
        gen ipw`suffix' = ip`suffix' / `denomvar'
    }

    * save
    keep ent ipw*
    save "`outfile'", replace
end

* ------------------------------------------------------------------------------
* Construct ICW for 1998-based analysis

* --- Program to make and save IPW
cap program drop makeipw98
program makeipw98
    syntax, ///
        indata_emp(string) /// employment data
        indata_chexp(string) /// change in exports data
        indata_denom(string) /// denominator data
        denomvar(string) /// denominator variable
        indcodevar(string) /// name of industry code variable
        outfile(string) /// output dataset name
        endyr(int) /// ending year

    * merge employment with predicted export changes
    use `indata_emp', clear
    merge m:1 `indcodevar' using `indata_chexp', keep(master match)
    if regexm("`outfile'", "_mex_") assert(_merge == 3 | rama == 3122)
    else if "`indcodevar'" == "rama" assert(_merge == 3)
    replace chexp`endyr' = 0 if _merge == 1

    * merge with denominator
    ren id_municipio id_mun
    merge m:1 id_mun using `indata_denom', keep(match) nogen keepusing(`denomvar')

    * construct instrument and save
    gen ipw`endyr' = (totemp1998 / natemp1998) * chexp`endyr' / `denomvar'
    collapse (sum) ipw`endyr', by(id_mun)
    compress
    save `outfile', replace
end
