/*

Programs to run analysis and produce tables for a given specification.

----------------------------------------------------------------------------- */

* --------- IV program

* IV (2sls) regression with outreg
cap program drop ivregout
program ivregout
    syntax [if] [aw], ///
        outvar(varname) /// outcome (dependent) variable
        instrmvars(varlist) /// instrumental variables (excluded instruments)
        endvar(varname) /// endogenous variable (instrumented for)
        [convars(string) /// control variables
        addrows(string asis) /// extra rows
        store(string) /// store results in table
        merge(string)] /// merge results with previous results in table

    * run regression, get r2 and mean, and outreg to tex
    ivregress 2sls `outvar' `convars' (`endvar'=`instrmvars') `if' [`weight'`exp'], robust
    qui: summ `outvar' if e(sample) [`weight'`exp']
    loc mean: di %5.2f `r(mean)'
    qui: estat firststage
    mat singleresults = r(singleresults)
    loc fstat: di %5.2f singleresults[1,4]
    if !mi("`addrows'") loc addrows = `"\ `addrows'"'
    outreg, tex varlabel nocons store(`store') merge(`merge') se bdec(2) nostars summstat(N) summtitles("Obs") keep(`endvar') addrows("First Stage F-stat", `fstat' \ "Mean of Dep Var" `mean' `addrows') nolegend
end

* ------------------------------------------------------------------------------
* First stage program

* OLS regression with outreg that shows statistics for first stage table
cap program drop fsout
program fsout
    syntax [if] [aw], ///
        outvar(varname) /// outcome (dependent) variable
        predvars(varlist) /// predictor variable(s) of interest
        [convars(string) /// control variables
        addrows(string asis) /// extra rows
        store(string) /// store results in table
        merge(string)] /// merge results with previous results in table

    * run auxillary regression for computing partial r2
    qui: regress `outvar' `convars' `if' [`weight'`exp']
    loc rss_reduced = e(rss)

    * run main regression, get r2 and partial r2, and outreg to tex
    regress `outvar' `convars' `predvars' `if' [`weight'`exp'], robust
    loc r2: di %4.3f e(r2)
    loc rss_full = e(rss)
    loc r2part: di %4.3f (`rss_reduced' - `rss_full') / `rss_reduced'
    if !mi("`addrows'") loc addrows = `"\ `addrows'"'
    outreg, tex varlabel nocons store(`store') merge(`merge') se bdec(2) nostars summstat(N) summtitles("Obs") keep(`predvars') addrows(R2, `r2' \ Partial R2, `r2part' `addrows') nolegend

    * check on partial r2 correctness when there is one predictor variable
    if `:list sizeof predvars' == 1 & !mi("`convars'") {
        qui: pcorr `outvar' `predvars' `convars' [`weight'`exp']
        mat pcorrs = r(p_corr)
        loc r2part_alt = pcorrs[1,1] ^ 2
        cap assert(float(round(`r2part_alt', 0.001)) == float(round(`r2part', 0.001)))
    }
end

* ------------------------------------------------------------------------------
* Prepares 2007-10/11 municipality-level data

cap program drop prepdata_main
program prepdata_main
    syntax, ///
        ipwdatalist(string asis) /// list of datasets with ipw
        pchjobsdata(string) /// dataset with pchjobs
        wtvar(string) /// weight variable
        data(string) /// output data file to save
        [ipwlabels(string asis) /// list of labels for IPW variables
        nostd] /// do not standardize pchjobs

    * use prepared municipality level data
    use "../data_prepped/maindata", clear

    * merge with pchjobs
    merge 1:1 id_mun using "../data_prepped/pchjobs/`pchjobsdata'", keep(match) nogen

    * merge with ipws
    loc ipwcount: list sizeof ipwdatalist
    forvalues i = 1/`ipwcount' {
        loc ipwdata: word `i' of `ipwdatalist'
        merge 1:1 id_mun using "../data_prepped/ipw/`ipwdata'", keep(match) nogen
        foreach v of var ipw2010 ipw2010_m ipw2010_f ipw2011 ipw2011_m ipw2011_f {
            ren `v' `v'_num`i'
        }
        if !mi(`"`ipwlabels'"') {
            loc ipwlabel: word `i' of `ipwlabels'
            loc ipwlabel = "[`ipwlabel']"
        }
        foreach v in ipw2010 ipw2011 ipw2010_m ipw2010_f {
            la var `v'_num`i' "$\Delta$ ICW `ipwlabel'"
        }
    }

    * divide instruments by 100,000 to be in units of 100,000 usd
    foreach v of var ipw*  {
        replace `v' = `v' / 100000
    }

    * standardize jobs change
    if "`std'" != "nostd" {
        foreach v of var pchjobs* {
            qui: summ `v' [aw=`wtvar']
            replace `v' = ((`v'- r(mean)) / r(sd))
        }
    }

    * label for outreg
    foreach v of var pchjobs2010 pchjobs2011 pchjobs2010_m pchjobs2010_f {
        la var `v' "$\%\Delta$ Jobs"
    }

    * drop rural and save
    drop if tipo_mun == "RU"
    save `data'
end

* ------------------------------------------------------------------------------
* Prepares 1998-2003 municipality-level data

cap program drop prepdata_9803
program prepdata_9803
    syntax, ///
        ipwdatalist(string asis) /// list of datasets with ipw
        pchjobsdata(string) /// dataset with pchjobs
        wtvar(string) /// weight variable
        data(string) /// output data file to save
        [ipwlabels(string asis) /// list of labels for IPW variables
        nostd] /// do not standardize pchjobs

    * use prepared municipality level data
    use "../data_prepped/maindata_9803", clear

    * merge with pchjobs
    merge 1:1 id_mun using "../data_prepped/pchjobs/9803/`pchjobsdata'", keep(match) nogen

    * merge with ipws
    loc ipwcount: list sizeof ipwdatalist
    forvalues i = 1/`ipwcount' {
        loc ipwdata: word `i' of `ipwdatalist'
        merge 1:1 id_mun using "../data_prepped/ipw/9803/`ipwdata'", assert(using match) keep(match) nogen
        ren ipw2003 ipw2003_num`i'
        if !mi(`"`ipwlabels'"') {
            loc ipwlabel: word `i' of `ipwlabels'
            loc ipwlabel = "[`ipwlabel']"
        }
        la var ipw2003_num`i' "$\Delta$ ICW `ipwlabel'"
    }

    * divide instruments by 100,000 to be in units of 100,000 usd
    foreach v of var ipw* {
        replace `v' = `v' / 100000
    }

    * keep emim sample
    keep if emimsamp

    * standardize jobs change
    if "`std'" != "nostd" {
        qui: summ pchjobs2003 [aw=`wtvar']
        replace pchjobs2003 = ((pchjobs2003 - r(mean)) / r(sd))
    }

    * label for outreg
    la var pchjobs2003 "$\%\Delta$ Jobs"

    * drop rural and save
    drop if tipo_mun == "RU"
    save "`data'", replace
end

* ------------------------------------------------------------------------------
* Prepares 1998-2013 municipality-level data

cap program drop prepdata_9813
program prepdata_9813
    syntax, ///
        ipwdatalist(string asis) /// list of datasets with ipw
        pchjobsdata(string) /// dataset with pchjobs
        wtvar(string) /// weight variable
        data(string) /// output data file to save
        [ipwlabels(string asis) /// list of labels for IPW variables
        nostd] /// do not standardize pchjobs

    * use prepared municipality level data
    use "../data_prepped/maindata_9813", clear

    * merge with pchjobs
    merge 1:1 id_mun using "../data_prepped/pchjobs/9813/`pchjobsdata'", keep(match) nogen

    * merge with ipws
    loc ipwcount: list sizeof ipwdatalist
    forvalues i = 1/`ipwcount' {
        loc ipwdata: word `i' of `ipwdatalist'
        merge 1:1 id_mun using "../data_prepped/ipw/9813/`ipwdata'", keep(match) nogen
        foreach v of var ipw2013* {
            if !regexm("`v'", "_num") ren `v' `v'_num`i'
        }
        if !mi(`"`ipwlabels'"') {
            loc ipwlabel: word `i' of `ipwlabels'
            loc ipwlabel = "[`ipwlabel']"
        }
        foreach v of var ipw2013*_num`i' {
            la var `v' "$\Delta$ ICW `ipwlabel'"
        }
    }

    * divide instruments by 100,000 to be in units of 100,000 usd
    foreach v of var ipw2013*  {
        replace `v' = `v' / 100000
    }

    * keep emim sample
    keep if emimsamp

    * standardize jobs change
    if "`std'" != "nostd" {
        foreach v of var pchjobs* {
            qui: summ `v' [aw=`wtvar']
            replace `v' = ((`v' - r(mean)) / r(sd))
        }
    }

    * label for outreg
    foreach v of var pchjobs2013* {
        la var `v' "$\%\Delta$ Jobs"
    }

    * drop rural and save
    drop if tipo_mun == "RU"
    save "`data'", replace
end

* ------------------------------------------------------------------------------
* Prepates state-level data for opinions regressions

cap program drop prepdata_state
program prepdata_state
    syntax, ///
        ipwdatalist(string asis) /// datasets with ipws
        pchjobsdata(string) /// dataset with pchjobs
        wtvar(string) /// what variable to weight by
        data(string) /// output data file to save
        [nostd] /// do not standardize pchjobs

    * --- Prepare data
    use "../data_prepped/maindata_state", clear

    * merge with pchjobs
    merge 1:1 ent using "../data_prepped/pchjobs/state/`pchjobsdata'", assert(master match) keep(match) nogen

    * merge with ipws
    loc ipwcount: list sizeof ipwdatalist
    forvalues i = 1/`ipwcount' {
        loc ipwdata: word `i' of `ipwdatalist'
        merge 1:1 ent using "../data_prepped/ipw/state/`ipwdata'", assert(using match) keep(match) nogen
        ren ipw2010 ipw2010_num`i'
        if !mi(`"`ipwlabels'"') {
            loc ipwlabel: word `i' of `ipwlabels'
            loc ipwlabel = "[`ipwlabel']"
        }
        la var ipw2010_num`i' "$\Delta$ ICW `ipwlabel'"
    }

    * divide instruments by 100,000 to be in units of 100,000 usd
    foreach v of var ipw*  {
        replace `v' = `v' / 100000
    }

    * standardize jobs change
    if "`std'" != "nostd" {
        qui: summ pchjobs2010 [aw=`wtvar']
        replace pchjobs2010 = (pchjobs2010 - r(mean)) / r(sd)
    }

    * label and save
    la var pchjobs2010 "$\%\Delta$ Jobs"
    save "`data'", replace
end

* ------------------------------------------------------------------------------
* Makes summary statistics table

cap program drop mksummstats
program mksummstats
    syntax, ///
        ipwdata_main(string asis) /// dataset with ipws
        pchjobsdata_main(string) /// dataset with pchjobs
        wtvar_main(string) /// what variable to weight by
        ipwdata98(string asis) /// ipw name for 98-03 and 98-13
        pchjobsdata98(string) /// pchjobs name for 98-03 and 98-13
        wtvar98(string) /// name of variable to weight by for 98-03 and 98-13
        outfldr(string) /// output folder

    * --- Make outfldr if it does not exist
    confirmdir "`outfldr'"
    if real(r(confirmdir)) mkdir "`outfldr'"

    * --- Prepare 2007-10/11
    tempfile mundata_main
    prepdata_main, ipwdatalist(`ipwdata_main') pchjobsdata("`pchjobsdata_main'") wtvar(`wtvar_main') data(`mundata_main') ipwlabels(`ipwlabels') nostd

    * --- Prepare 1998-2013
    tempfile mundata_9813
    prepdata_9813, ipwdatalist(`ipwdata98') pchjobsdata("`pchjobsdata98'") wtvar(`wtvar98') data(`mundata_9813') ipwlabels(`ipwlabels') nostd

    * --- Prepare 1998-2003
    tempfile mundata_9803
    prepdata_9803, ipwdatalist(`ipwdata98') pchjobsdata("`pchjobsdata98'") wtvar(`wtvar98') data(`mundata_9803') ipwlabels(`ipwlabels') nostd

    * --------------------------------------------------------------------------
    * Compute Statistics

    * --- ICW
    use `mundata_main', clear
    summ ipw2010_num1 [aw=`wtvar_main']
    mat icw = (r(mean), r(sd))
    summ ipw2011_num1 [aw=`wtvar_main']
    mat icw = icw \ (r(mean), r(sd))
    use `mundata_9803', clear
    summ ipw2003 [aw=`wtvar98']
    mat icw = icw \ (r(mean), r(sd))
    use `mundata_9813', clear
    summ ipw2013_num1 [aw=`wtvar98']
    mat icw = icw \ (r(mean), r(sd))

    * --- Change in jobs
    use `mundata_main', clear
    summ pchjobs2010 [aw=`wtvar_main']
    mat emp = (r(mean), r(sd))
    summ pchjobs2011 [aw=`wtvar_main']
    mat emp = emp \ (r(mean), r(sd))
    use `mundata_9803', clear
    summ pchjobs2003 [aw=`wtvar98']
    mat emp = emp \ (r(mean), r(sd))
    use `mundata_9813', clear
    summ pchjobs2013 [aw=`wtvar98']
    mat emp = emp \ (r(mean), r(sd))

    * --- Homicides
    use `mundata_main', clear
    summ homdiff_inegi_ratelong3 [aw=`wtvar_main'] if !mi(pchjobs2010)
    mat allhom = (r(mean), r(sd))
    summ homdiff_inegi_ratelong4 [aw=`wtvar_main'] if !mi(pchjobs2011)
    mat allhom = allhom \ (r(mean), r(sd))
    use `mundata_9803', clear
    summ homdiff_9803 [aw=`wtvar98'] if !mi(pchjobs2003)
    mat allhom = allhom \ (r(mean), r(sd))
    use `mundata_9813', clear
    summ homdiff_9813 [aw=`wtvar98'] if !mi(pchjobs2013)
    mat allhom = allhom \ (r(mean), r(sd))

    * --- Drug-Related Homicides
    use `mundata_main', clear
    summ homdiff_rate_long3 [aw=`wtvar_main'] if !mi(pchjobs2010)
    mat drhom = (r(mean), r(sd))

    * --- Cocaine seizures
    use `mundata_main', clear
    summ logValueFor_total3diff [aw=`wtvar_main'] if !mi(pchjobs2010)
    mat coc = (r(mean), r(sd))
    summ logValueFor_total4diff [aw=`wtvar_main'] if !mi(pchjobs2011)
    mat coc = coc \ (r(mean), r(sd))
    use `mundata_9803', clear
    summ logValueFor_diff9803 [aw=`wtvar98'] if !mi(pchjobs2003)
    mat coc = coc \ (r(mean), r(sd))

    * --- Non-Cocaine seizures
    use `mundata_main', clear
    summ logValueDom_total3diff [aw=`wtvar_main'] if !mi(pchjobs2010)
    mat ncoc = (r(mean), r(sd))
    summ logValueDom_total4diff [aw=`wtvar_main'] if !mi(pchjobs2011)
    mat ncoc = ncoc \ (r(mean), r(sd))
    use `mundata_9803', clear
    summ logValueDom_diff9803 [aw=`wtvar98'] if !mi(pchjobs2003)
    mat ncoc = ncoc \ (r(mean), r(sd))

    * --------------------------------------------------------------------------
    * Make the Latex Table

    foreach mat in icw emp allhom drhom coc ncoc {
        forvalues i = 1/4 {
            if !mi(`mat'[`i', 1]) {
                loc mean`i' = trim(string(`mat'[`i', 1], "%10.2f"))
                loc sd`i' = "("+trim(string(`mat'[`i', 2], "%10.2f"))+")"
            }
            else {
                loc mean`i' = "-"
                loc sd`i' = "-"
            }
            loc `mat'_mean_expr = "``mat'_mean_expr' & `mean`i''"
            loc `mat'_sd_expr = "``mat'_sd_expr' & `sd`i''"
        }
    }
    file open t1 using "`outfldr'/t1.tex", write replace
    file write t1 "\begin{tabular}{lcccc}" _n
    file write t1 "\hline\noalign{\smallskip} & $\Delta$2007-2010 & $\Delta$2007-2011 & $\Delta$1998-2003 & $\Delta$ 1998-2013 \\" _n
    file write t1 "\cmidrule(lr{.75em}){2-3}\cmidrule(lr{.75em}){4-5}" _n
    file write t1 "& (1) & (2) & (3) & (4) \\" _n
    file write t1 "\noalign{\smallskip}\hline\noalign{\smallskip} ICW `icw_mean_expr' \\" _n
    file write t1 "`icw_sd_expr' \\" _n
    file write t1 "Manuf. Employment Rate `emp_mean_expr' \\" _n
    file write t1 "`emp_sd_expr' \\" _n
    file write t1 "Homicides `allhom_mean_expr' \\" _n
    file write t1 "\quad Per 100,000 `allhom_sd_expr' \\" _n
    file write t1 "Drug-Related Homicides `drhom_mean_expr' \\" _n
    file write t1 "\quad Per 100,000 `drhom_sd_expr' \\" _n
    file write t1 "Log Cocaine Seizures `coc_mean_expr' \\" _n
    file write t1 "`coc_sd_expr' \\" _n
    file write t1 "Log Non-Cocaine Seizures `ncoc_mean_expr' \\" _n
    file write t1 "`ncoc_sd_expr' \\" _n
    file write t1 "\noalign{\smallskip}\hline\end{tabular}" _n
    file close t1
end

* ------------------------------------------------------------------------------
* Makes main tables

cap program drop maketables_main
program maketables_main
    syntax, ///
        ipwdatalist_main(string asis) /// dataset with ipws
        pchjobsdata_main(string) /// dataset with pchjobs
        wtvar_main(string) /// what variable to weight by
        ipwdatalist98(string asis) /// ipw name for 98-03 and 98-13
        pchjobsdata98(string) /// pchjobs name for 98-03 and 98-13
        wtvar98(string) /// name of variable to weight by for 98-03 and 98-13
        outfldr(string) /// output folder
        [convars_main(string) /// control variables for most muni regs
        convars_state(string) /// control variables for state
        convars_pp_core(string) /// core control varibles for preperiod
        convars_pp_prefix(string) /// prefixes of other con vars for preperiod
        convars98(string) /// control variables for 1998-2013 and 1998-2003
        ipwlabels(string asis) /// list of labels for IPW variables
        nostd] /// do not standardize pchjobs

    * --- Make outfldr if it does not exist
    confirmdir "`outfldr'"
    if real(r(confirmdir)) mkdir "`outfldr'"

    * --- Prepare 1998-2013
    tempfile mundata_9813
    prepdata_9813, ipwdatalist(`ipwdatalist98') pchjobsdata("`pchjobsdata98'") wtvar(`wtvar98') data(`mundata_9813') ipwlabels(`ipwlabels') `std'

    * --- Prepare 1998-2003
    tempfile mundata_9803
    prepdata_9803, ipwdatalist(`ipwdatalist98') pchjobsdata("`pchjobsdata98'") wtvar(`wtvar98') data(`mundata_9803') ipwlabels(`ipwlabels') `std'

    * --- Prepare 2007-10/11
    tempfile mundata_main
    prepdata_main, ipwdatalist(`ipwdatalist_main') pchjobsdata("`pchjobsdata_main'") wtvar(`wtvar_main') data(`mundata_main') ipwlabels(`ipwlabels') `std'

    * --- Prepare state data
    tempfile statedata
    prepdata_state, ipwdatalist(`ipwdatalist_main') pchjobsdata("`pchjobsdata_main'") wtvar(`wtvar_main') data(`statedata') `std'

    * --------------------------------------------------------------------------
    * Table 1: first stage and violence

    * 1998-2013
    use `mundata_9813', clear
    ivregout [aw=`wtvar98'], outvar(homdiff_9813) instrmvars(ipw2013_num*) endvar(pchjobs2013) convars(`convars98') store(t1a) addrows(Homicide Type, All)
    fsout [aw=`wtvar98'], outvar(pchjobs2013) predvars(ipw2013_num*) convars(`convars98') store(t1b)

    * 1998-2003
    use `mundata_9803', clear
    ivregout [aw=`wtvar98'], outvar(homdiff_9803) instrmvars(ipw2003_num*) endvar(pchjobs2003) convars(`convars98') merge(t1a) addrows(Homicide Type, All)
    fsout [aw=`wtvar98'], outvar(pchjobs2003) predvars(ipw2003_num*) convars(`convars98') merge(t1b)

    * 2007-2010/11 violence
    use `mundata_main', clear
    ivregout [aw=`wtvar_main'], outvar(homdiff_inegi_ratelong3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t1a) addrows(Homicide Type, All)
    ivregout [aw=`wtvar_main'], outvar(homdiff_rate_long3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t1a) addrows(Homicide Type, Drug-Related)
    ivregout [aw=`wtvar_main'], outvar(homdiff_inegi_ratelong4) instrmvars(ipw2011_num*) endvar(pchjobs2011) convars(`convars_main') merge(t1a) addrows(Homicide Type, All)
    ivregout [aw=`wtvar_main'], outvar(homdiff_rate_long3) instrmvars(ipw2010_m_num*) endvar(pchjobs2010_m) convars(`convars_main') merge(t1a) addrows(Homicide Type, Drug-Related)
    ivregout [aw=`wtvar_main'], outvar(homdiff_rate_long3) instrmvars(ipw2010_f_num*) endvar(pchjobs2010_f) convars(`convars_main') merge(t1a) addrows(Homicide Type, Drug-Related)

    * 2007-2010/11 first stage
    fsout [aw=`wtvar_main'], outvar(pchjobs2010) predvars(ipw2010_num*) convars(`convars_main') merge(t1b)
    fsout [aw=`wtvar_main'], outvar(pchjobs2010) predvars(ipw2010_num*) convars(`convars_main') merge(t1b)
    fsout [aw=`wtvar_main'], outvar(pchjobs2011) predvars(ipw2011_num*) convars(`convars_main') merge(t1b)
    fsout [aw=`wtvar_main'], outvar(pchjobs2010_m) predvars(ipw2010_m_num*) convars(`convars_main') merge(t1b)
    fsout [aw=`wtvar_main'], outvar(pchjobs2010_f) predvars(ipw2010_f_num*) convars(`convars_main') merge(t1b)

    * make table
    loc hrule = "\noalign{\smallskip}\hline\noalign{\smallskip}"
    if mi(`"`ipwlabels'"') loc rt_ipw = `" $\Delta$ ICW" \ ""'
    else {
        foreach ipwlabel of loc ipwlabels {
            loc rt_ipw = `" `rt_ipw'$\Delta$ ICW" \ "\quad [`ipwlabel']" \ ""'
        }
        loc rt_ipw = substr(`"`rt_ipw'"', 1, strlen(`"`rt_ipw'"') - 5)
    }
    outreg using "`outfldr'/t1.tex", replay(t1a) append(t1b) replace tex plain fragment nocenter spacebef(10001{0}) spaceaft(0001{0}1) ///
        ctitles("", "", "", "", "", "", "Low-Skill", "Residual" \ "", "", "", "", "", "", , "Young Men", "Group" \ "", "1998-2013", "1998-2003", "2007-2010", "2007-2010", "2007-2011", "2007-2010", "2007-2010" \ "", (1), (2), (3), (4), (5), (6), (7)) ///
        rtitles("\textit{Panel A: Violence} & \multicolumn{7}{c}{Dependent Variable is Change in Homicide Rate} \\ \noalign{\smallskip}\cline{2-8}\noalign{\smallskip} $\%\Delta$ Jobs" \ "" \ "Obs" \ "First Stage F-Stat" \ "Mean of Dep Var" \ "Homicide Type" \ ///
        "`hrule' \emph{Panel B: First Stage} & \multicolumn{7}{c}{Dependent Variable is Percent Change Jobs} \\ \noalign{\smallskip}\cline{2-8}\noalign{\smallskip} `rt_ipw'" \ "Obs" \ "R2" \ "Partial R2")

    * --------------------------------------------------------------------------
    * Table 2: Violence, DTOs, and Seizures

    * all homicides
    ivregout [aw=`wtvar_main'], outvar(homdiff_inegi_ratelong3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') store(t2a)
    ivregout if cartel == 0 [aw=`wtvar_main'], outvar(homdiff_inegi_ratelong3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2a)
    ivregout if cartel == 1 [aw=`wtvar_main'], outvar(homdiff_inegi_ratelong3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2a)
    ivregout if C_major == 1 [aw=`wtvar_main'], outvar(homdiff_inegi_ratelong3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2a)

    * drug-related homicides
    ivregout [aw=`wtvar_main'], outvar(homdiff_rate_long3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') store(t2b)
    ivregout if cartel == 0 [aw=`wtvar_main'], outvar(homdiff_rate_long3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2b)
    ivregout if cartel == 1 [aw=`wtvar_main'], outvar(homdiff_rate_long3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2b)
    ivregout if C_major == 1 [aw=`wtvar_main'], outvar(homdiff_rate_long3) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2b)
    outreg, store(t2) replay(t2a) append(t2b)

    * cocaine seizures
    ivregout [aw=`wtvar_main'], outvar(logValueFor_total3diff) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') store(t2c)
    ivregout if cartel == 0 [aw=`wtvar_main'], outvar(logValueFor_total3diff) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2c)
    ivregout if cartel == 1 [aw=`wtvar_main'], outvar(logValueFor_total3diff) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2c)
    ivregout if C_major == 1 [aw=`wtvar_main'], outvar(logValueFor_total3diff) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2c)
    outreg, store(t2) replay(t2) append(t2c)

    * non-cocaine seizures
    ivregout [aw=`wtvar_main'], outvar(logValueDom_total3diff) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') store(t2d)
    ivregout if cartel == 0 [aw=`wtvar_main'], outvar(logValueDom_total3diff) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2d)
    ivregout if cartel == 1 [aw=`wtvar_main'], outvar(logValueDom_total3diff) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2d)
    ivregout if C_major == 1 [aw=`wtvar_main'], outvar(logValueDom_total3diff) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t2d)
    outreg, store(t2) replay(t2) append(t2d)

    * make table
    loc hrule = "\noalign{\smallskip}\hline\noalign{\smallskip}"
    loc rts = `" "" \ "Obs" \ "F-stat" \ "Mean of Dep Var" "'
    loc pchjobslabel = "$\%\Delta$ Jobs 2007-2010"
    outreg using "`outfldr'/t2", replay(t2) replace tex plain fragment nocenter spaceaft(01{0}1) spacebef(101{0}) ///
        ctitles("Sample:", "All", "No DTO", "Any DTO", "Major DTO" \ "", (1), (2), (3), (4)) ///
        rtitles("\textit{Panel A: $\Delta$ Total Homicide Rate}\\ `pchjobslabel'" \ `rts' \ "`hrule'\textit{Panel B: $\Delta$ Drug-Related Homicide Rate}\\ `pchjobslabel'" \ `rts' \ "`hrule'\textit{Panel C: $\Delta$ Log Cocaine Seizures}\\ `pchjobslabel'" \ `rts' \ "`hrule'\textit{Panel D: $\Delta$ Log Non-Cocaine Seizures}\\ `pchjobslabel'" \ `rts')

    * --------------------------------------------------------------------------
    * Table 3: pre-period outcomes

    * --- Merge main data with preperiod data
    use `mundata_main', clear
    merge 1:1 id_mun using "../data_prepped/maindata_preperiod"
    assert(mi(share0)) if _merge == 1
    drop if _merge != 3
    drop _merge

    * --- Make lists of control variables for regressions
    forvalues year = 1992(3)2004 {
        loc convars_pp_`year' = "`convars_pp_core'"
        foreach v in `convars_pp_prefix' {
            loc convars_pp_`year' = "`convars_pp_`year'' `v'`year'"
        }
    }

    * --- Run regressions and make IV table
    forvalues startyear = 1992(3)2004 {
        loc endyear = `startyear' + 3

        * column 1: homicide changes
        ivregout [aw=`wtvar_main'], outvar(homdiff_`startyear'_`endyear') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_pp_`startyear'') store(t_`startyear') addrows(Sample, All)

        * column 2: homicide changes, any dto only
        ivregout [aw=`wtvar_main'] if cartel, outvar(homdiff_`startyear'_`endyear') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_pp_`startyear'') merge(t_`startyear') addrows(Sample, Any DTO)

        * column 3: log foreign confiscation value changes
        ivregout [aw=`wtvar_main'], outvar(lvalFor_diff_`startyear'_`endyear') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_pp_`startyear'') merge(t_`startyear') addrows(Sample, All)

        * column 4: log foreign confiscation value changes, any dto only
        ivregout [aw=`wtvar_main'] if cartel, outvar(lvalFor_diff_`startyear'_`endyear') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_pp_`startyear'') merge(t_`startyear') addrows(Sample, Any DTO)

        * column 5: log domestic confiscation value changes
        ivregout [aw=`wtvar_main'], outvar(lvalDom_diff_`startyear'_`endyear') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_pp_`startyear'') merge(t_`startyear') addrows(Sample, All)

        * column 6: log domestic confiscation value changes, any dto only
        ivregout [aw=`wtvar_main'] if cartel, outvar(lvalDom_diff_`startyear'_`endyear') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_pp_`startyear'') merge(t_`startyear') addrows(Sample, Any DTO)

        * append to other panels
        if `startyear' == 1992 outreg, replay(t_1992) store(t_all)
        else outreg, replay(t_all) append(t_`startyear') store(t_all)
    }

    * produce table
    loc hrule = "\noalign{\smallskip}\hline\noalign{\smallskip}"
    loc rts = `" "" \ "Obs" \ "F-stat" \ "Mean of Dep Var" \ "Sample""'
    loc pchjobslabel = "$\%\Delta$ Jobs 2007-2010"
    outreg using "`outfldr'/t3", replay(t_all) replace tex plain fragment nocenter multicol(1, 4, 2; 1, 6, 2; 2, 2, 2; 2, 4, 2; 2, 6, 2) spaceaft(001{0}1) spacebef(1001{0}) ///
        ctitles("", "", "", "$\Delta$ Log Value", "", "$\Delta$ Log Value" \ "Dep Var Is:", "$\Delta$ Homicide Rate", "", "Cocaine Seizures", "", "Non-Coc. Seizures" \ "", (1), (2), (3), (4), (5), (6)) ///
        rtitles("\textit{Panel A: 1992-1995}\\ `pchjobslabel'" \ `rts' \ "`hrule'\textit{Panel B: 1995-1998}\\ `pchjobslabel'" \ `rts' \ "`hrule'\textit{Panel C: 1998-2001}\\ `pchjobslabel'" \ `rts' \ "`hrule'\textit{Panel D: 2001-2004}\\ `pchjobslabel'" \ `rts' \ "`hrule'\textit{Panel E: 2004-2007}\\ `pchjobslabel'" \ `rts')

    * --------------------------------------------------------------------------
    * Table 4: Political and opinion outcomes

    * state-level opinion outcomes
    use `statedata', clear
    la var pchjobs2010 "$\%\Delta$ Jobs 2007-10"
    ivregout [aw=`wtvar_main'], outvar(homdiff_rate_long3ent) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_state') store(t4) addrows(Unit, State \ Sample, All)
    foreach v in pol_contribute opportunity status_dem {
        ivregout [aw=`wtvar_main'], outvar(diff`v') instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_state') merge(t4) addrows(Unit, State \ Sample, All)
    }

    * mayor changes
    use `mundata_main', clear
    la var pchjobs2010 "$\%\Delta$ Jobs 2007-10"
    ivregout [aw=`wtvar_main'], outvar(anychange0710) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t4) addrows(Unit, Muni. \ Sample, All)
    ivregout [aw=`wtvar_main'] if cartel == 0, outvar(anychange0710) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t4) addrows(Unit, Muni. \ Sample, No DTO)
    ivregout [aw=`wtvar_main'] if cartel == 1, outvar(anychange0710) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t4) addrows(Unit, Muni. \ Sample, Any DTO)
    ivregout [aw=`wtvar_main'] if C_major == 1, outvar(anychange0710) instrmvars(ipw2010_num*) endvar(pchjobs2010) convars(`convars_main') merge(t4) addrows(Unit, Muni. \ Sample, Major DTO)

    * produce table
    outreg using "`outfldr'/t4.tex", replay(t4) replace tex plain fragment nocenter ctitles("", "", "Change in Agreement (2005-12)" \ "\noalign{\smallskip}\cline{3-5}\noalign{\smallskip}", "$\Delta$ Homicide", "Politicians", "More" \ "", "Rate", "Improve", "Opportunities", "Mexico is" \ "", "(2007-10)", "Wellbeing",  "Than in Past", "Democratic", "Any Change in Party of Mayor (2007-10)" \ "", (1), (2), (3), (4), (5), (6), (7), (8)) spacebef(100001{0}) spaceaft(00001{0}1) multicol(1, 3, 3; 2, 6, 2; 2, 8, 2; 4, 6, 4)
end
